@echo off
setlocal

title BioMap Installation for Windows
color F0

rem get environment variables
set bdir=%ProgramFiles%\BioMap
set ldir=%cd%
set ldir=%~d0%~p0
set udir=%APPDATA%\BioMap
set upars=%APPDATA%\BioMap\uparsrc

cls
echo.
echo BioMap installation script
echo ==========================
echo.
echo This script will install BioMap and/or copy the settings to the user directory.


   rem check if BioMap is installed in local directory
   if "%ldir%"=="%bdir%" goto usave

   if not "%ldir%"=="%SYSTEMROOT%" goto aask

   echo.
   echo Cannot install from network path. Mount path as drive and restart script.
   goto end


:aask
   echo.
   echo.
   echo Installing program files
   echo ------------------------
   echo.
   echo This script was not started from the default BioMap directory.
   echo You can run BioMap from the current location or install it to the default
   echo location.
   echo.
   echo Current directory: %ldir%
   echo Default directory: %bdir%

:aretry   
   echo.
   set /p in=Do you want to install BioMap to the default directory (y/n)? 
      if /i %in%==y goto acopy
      if /i %in%==n goto aother
      if /i %in%==^C goto end
      @echo Invalid input
   goto aretry
   

:acopy
   rem Check if the BioMap dir exists?
   if not exist "%bdir%\" goto adir
   echo.
   echo An existing BioMap installation was found.

:cask
   echo.
   set /p in=Do you want to replace the existing installation (y/n)? 
      if /i %in%==y goto astart
      if /i %in%==n goto aend
      if /i %in%==^C goto end
      @echo Invalid input
   goto cask

:adir
   rem OK, create dir
   mkdir "%bdir%"
   if errorlevel 0 goto astart
      echo.
      echo Could not create directory, installation aborted...
      echo.
      pause
   goto end

:astart
   rem check if directory is writable
   if exist "%bdir%\bin\biomap.sav" del "%bdir%\bin\biomap.sav" /q >nul
   if not exist "%bdir%\bin\biomap.sav" goto anext
      echo.
      echo  Could not access installation directory, installation aborted...
      echo.
   goto end

:anext
   echo Start copying...
   xcopy "%ldir%*.*" "%bdir%" /e /q /c /y >nul
   echo.
   echo BioMap was installed to the default path.
   if exist "%bdir%\bin\biomap.sav" goto aend
      echo.
      echo Could not access installation directory, installation aborted...
      echo.
   goto end

:aother
   echo.
   echo The application path in the user settings will point to the
   echo current directory. If you move BioMap later to a different location,
   echo execute this script again.

:aend



:usave
   rem save uparsrc

   echo.
   echo.   
   echo Installing user settings
   echo ------------------------

   rem uparsrc exists?
   if not exist "%upars%" goto ucreate


   echo.
   echo Your application directory already contains BioMap settings.

:uask
   echo.
   set /p in=Do you want to overwrite the existing settings with default values (y/n)? 
      if /i %in%==y goto ucreate
      if /i %in%==n goto uend
      if /i %in%==^C goto end
   @echo Invalid input
   goto uask

:ucreate

      if not exist "%bdir%\bin\biomap.sav" set bdir=%ldir%

      xcopy "%ldir%\settings\*.*" "%udir%\*.*" /e /q /c /y >nul

      echo BIOMAPDIR = '%bdir%\' >"%upars%"
      echo TEMPDIR = '%TEMP%\' >>"%upars%"
      echo USERDIR = '%udir%\' >>"%upars%"
      echo BRUKER_IMAGE_DIR = '%HOMEDRIVE%\' >>"%upars%"
      echo ANALYZE_IMAGE_DIR = '%HOMEDRIVE%\' >>"%upars%"
      echo ANALYZE_STORAGE_MODE = 0 >>"%upars%"
      echo ANALYZE_ACCESS_MODE = 'g' >>"%upars%"
      echo DICOM_IMAGE_DIR = '%HOMEDRIVE%\' >>"%upars%"
      echo MSI_IMAGE_DIR = '%HOMEDRIVE%\' >>"%upars%"
      echo NIF_IMAGE_DIR = '%HOMEDRIVE%\' >>"%upars%"
      echo PIXMAP_IMAGE_DIR = '%HOMEDRIVE%\' >>"%upars%"
      echo EXPORT_DIR = '%HOMEDRIVE%\' >>"%upars%"
      echo DEFAULTPRINTER = '' >>"%upars%"
      echo SIMULATIONDIR = '' >>"%upars%"
      echo SHOWREVISIONFLAG = 3 >>"%upars%"
      echo RGBCOLOR_ACTIVEFRAME = [255, 0, 0] >>"%upars%"
      echo RGBCOLOR_WINDOWGRID = [0, 100, 255] >>"%upars%"
      echo RGBCOLOR_ANNOTATION = [255, 255, 0] >>"%upars%"
      echo RGBCOLOR_ROILIST = [0, 255, 255] >>"%upars%"
      echo WINDOWFONT = 'Helvetica*12'>>"%upars%"
      echo TIFFCOMPRESSIONMODE = 0 >>"%upars%"
      echo MULTIWINDOWXSIZE = 800 >>"%upars%"
      echo MULTIWINDOWNCOL = 6 >>"%upars%"
      echo AUTOSCALINGEXCLUDE = 4.00000 >>"%upars%"
      echo AUTOSCALINGINCLUDE = 0.950000 >>"%upars%"
      echo LAYOUT = 'L4x4' >>"%upars%"
      echo BIOMAPWINDOWSIZE = [0, 0] >>"%upars%
      echo BIOMAPWINDOWATTR = [0, 0] >>"%upars%

      echo.
      echo Settings were copied to the user directory.
:uend

   echo.
   echo Next steps...
   echo -------------
   echo.
   echo 1. Start BioMap by double-clicking on biomap.sav in the /bin directory
   echo 2. Get a license from http://www.maldi-msi.org
   echo 3. Create a shortcut to biomap.sav on the desktop using the icon provided
   echo    in the biomap folder.
   echo.
   
   pause
   explorer http://www.maldi-msi.org/software/register.htm
   explorer %bdir%\bin   
   goto finish    

:end
echo.
pause
:finish